@@ -20,7 +20,7 @@
 #include "umldoc.h"
 
 // kde includes
-#include <klocale.h>
+#include <KLocalizedString>
 
 /**
  * Constructor.
@@ -157,4 +157,3 @@ void UMLClassifierListItem::setTypeName(const QString &type)
     UMLObject::emitModified();
 }
 
-#include "classifierlistitem.moc"
