@@ -18,13 +18,18 @@
 #include "umlwidget.h"
 
 // kde includes
+#if QT_VERSION < 0x050000
 #include <kinputdialog.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#endif
+#include <KMessageBox>
+#include <KLocalizedString>
 #include <klineedit.h>
 #include <kcombobox.h>
 
 // qt includes
+#if QT_VERSION >= 0x050000
+#include <QInputDialog>
+#endif
 #include <QGridLayout>
 #include <QLabel>
 #include <QLineEdit>
@@ -69,7 +74,14 @@ void askNameForWidget(UMLWidget * &targetWidget, const QString& dialogTitle,
 {
     bool pressedOK = false;
 
+#if QT_VERSION >= 0x050000
+    QString name = QInputDialog::getText(UMLApp::app(),
+                                         dialogTitle, dialogPrompt,
+                                         QLineEdit::Normal,
+                                         defaultName, &pressedOK);
+#else
     QString name = KInputDialog::getText(dialogTitle, dialogPrompt, defaultName, &pressedOK, UMLApp::app());
+#endif
 
     if (pressedOK) {
         targetWidget->setName(name);
@@ -80,6 +92,26 @@ void askNameForWidget(UMLWidget * &targetWidget, const QString& dialogTitle,
     }
 }
 
+/**
+ * Helper function for requesting a name using a dialog.
+ *
+ * @param title           Title of the dialog.
+ * @param prompt          Prompt of the dialog.
+ * @param name            Default value of the name field.
+ * @return true on user pressed okay
+ * @return false on user pressed cancel
+ */
+bool askName(const QString& title, const QString& prompt, QString& name)
+{
+    bool ok;
+#if QT_VERSION >= 0x050000
+     name = QInputDialog::getText((QWidget*)UMLApp::app(), title, prompt, QLineEdit::Normal, name, &ok);
+#else
+     name = KInputDialog::getText(title, prompt, name, &ok, (QWidget*)UMLApp::app());
+#endif
+     return ok;
+}
+
 /**
  * Helper function for inserting available stereotypes into a KComboBox
  *
