@@ -50,6 +50,7 @@ public:
         ShowOperationSignature = 0x60,  ///< only in setter
         ShowAttributeSignature = 0x80,   ///< only in setter
         DrawAsPackage          = 0x100,
+        ShowDocumentation      = 0x200,
     };
 
     Q_DECLARE_FLAGS(VisualProperties, VisualProperty)
@@ -95,6 +96,8 @@ public:
     UMLWidget* onWidget(const QPointF& p);
     UMLWidget* widgetWithID(Uml::ID::Type id);
 
+    virtual void setDocumentation(const QString& doc);
+
     QSizeF calculateSize(bool withExtensions = true) const;
 
     virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
